"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const state = require("@codemirror/state");
const ImmutableSetUtils = /* @__PURE__ */ Object.freeze({
  add: (set, value) => {
    if (set.has(value)) {
      return set;
    }
    const newSet = new Set(set);
    newSet.add(value);
    return newSet;
  },
  delete: (set, value) => {
    if (!set.has(value)) {
      return set;
    }
    const newSet = new Set(set);
    newSet.delete(value);
    return newSet;
  },
  clear: (set) => {
    if (!set.size) {
      return set;
    }
    return /* @__PURE__ */ new Set();
  },
  wrap: (set) => {
    const _ = ImmutableSetUtils;
    return {
      add: (value) => _.wrap(_.add(set, value)),
      addMany: (values = []) => _.wrap(values.reduce(_.add, set)),
      delete: (value) => _.wrap(_.delete(set, value)),
      deleteMany: (values = []) => _.wrap(values.reduce(_.delete, set)),
      clear: () => _.wrap(_.clear(set)),
      unwrap: () => set
    };
  }
});
function rangeSetsEqual(a, b) {
  return state.RangeSet.eq([b], [a]);
}
function mapRangeSetToArray(rangeSet, callbackfn) {
  const values = new Array(rangeSet.size);
  if (values.length) {
    let index = 0;
    for (const cursor = rangeSet.iter(); cursor.value !== null; cursor.next()) {
      values[index++] = callbackfn(cursor.value, cursor.from, cursor.to);
    }
  }
  return values;
}
function reduceRangeSet(rangeSet, callbackfn, initialValue) {
  if (!rangeSet.size) {
    if (initialValue == null) {
      throw new TypeError("Reduce of empty RangeSet with no initial value");
    }
    return initialValue;
  }
  const cursor = rangeSet.iter();
  let accumulator;
  if (initialValue == null) {
    accumulator = cursor.value;
    cursor.next();
  } else {
    accumulator = initialValue;
  }
  for (; cursor.value !== null; cursor.next()) {
    accumulator = callbackfn(accumulator, cursor.value, cursor.from, cursor.to);
  }
  return accumulator;
}
function isEffectOfType(type) {
  return (effect) => effect.is(type);
}
function mapEffectValue(arg1, arg2) {
  return typeof arg1 === "function" ? (effect) => arg1(effect.value) : arg2(arg1.value);
}
exports.ImmutableSetUtils = ImmutableSetUtils;
exports.isEffectOfType = isEffectOfType;
exports.mapEffectValue = mapEffectValue;
exports.mapRangeSetToArray = mapRangeSetToArray;
exports.rangeSetsEqual = rangeSetsEqual;
exports.reduceRangeSet = reduceRangeSet;
//# sourceMappingURL=index.cjs.map
